@@ -5,11 +5,11 @@ Use with listing methods to filter the results.
 
         srf.trips.find_all(distance=between(0, 50))
 
-Related entities can be traversed, which required using dict syntax:
+Related entities can be traversed, which requires using dict syntax:
 
     .. code:: python
 
-        srf.trips.find_all(**{vehicle.make=eq('Scania')})
+        srf.trips.find_all(**{'vehicle.make': eq('Scania')})
 
 .. warning::
     Using unsupported operators for a field type will give unexpected
